Index: trunk/psLib/src/sys/psLogMsg.h
===================================================================
--- trunk/psLib/src/sys/psLogMsg.h	(revision 1807)
+++ trunk/psLib/src/sys/psLogMsg.h	(revision 2204)
@@ -11,6 +11,6 @@
  *  @author George Gusciora, MHPCC
  *
- *  @version $Revision: 1.18 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-09-14 20:01:52 $
+ *  @version $Revision: 1.19 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -19,5 +19,6 @@
 #define PS_LOG_MSG_H
 #include <stdarg.h>
-#include <stdbool.h>
+
+#include "psType.h"
 
 /** @addtogroup LogTrace
@@ -31,7 +32,7 @@
  *  argument which can specify more general log destinations.
  *
  *  @return int     true if set successfully, otherwise false.
  */
-bool psLogSetDestination(
+psBool psLogSetDestination(
     const char *dest                   ///< Specifies where to send messages.
 );
@@ -43,8 +44,8 @@
  *  be displayed.
  *
  *  @return int    old logging level
  */
-int psLogSetLevel(
-    int level                          ///< Specifies the system log level
+psS32 psLogSetLevel(
+    psS32 level                          ///< Specifies the system log level
 );
 
@@ -68,5 +69,5 @@
 void psLogMsg(
     const char *name,                  ///< name of the log source
-    int myLevel,                       ///< severity level of this log message
+    psS32 myLevel,                       ///< severity level of this log message
     const char *fmt,                   ///< printf-style format command
     ...
@@ -79,5 +80,5 @@
 void psLogMsgV(
     const char *name,                  ///< name of the log source
-    int myLevel,                       ///< severity level of this log message
+    psS32 myLevel,                       ///< severity level of this log message
     const char *fmt,                   ///< printf-style format command
     va_list ap                         ///< varargs argument list
@@ -31,7 +32,7 @@
  *  argument which can specify more general log destinations.
  *
- *  @return int     true if set successfully, otherwise false.
+ *  @return psS32     true if set successfully, otherwise false.
  */
@@ -43,8 +44,8 @@
  *  be displayed.
  *
- *  @return int    old logging level
+ *  @return psS32    old logging level
  */
